#ifndef Rcpp_wrap_wrap_h
#define Rcpp_wrap_wrap_h
 
#include <Rcpp/wrap/make_charsexp.h>

#include <Rcpp/wrap/wrap_impl.h>

#include <Rcpp/wrap/Wrapper.h>     
#include <Rcpp/wrap/PrimitiveWrapper.h>     
#include <Rcpp/wrap/EnumWrapper.h>     
#include <Rcpp/wrap/MatrixWrapper.h>     
#include <Rcpp/wrap/ContainerWrapper.h>
#include <Rcpp/wrap/SexpConvertibleWrapper.h>
#include <Rcpp/wrap/SugarExpressionWrapper.h>
#include <Rcpp/wrap/LazyVectorWrapper.h>

#include <Rcpp/wrap/wrap_type.h>     

#endif
